Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNino van Hooff <ninovanhooff@gmail.com>2020-02-14 18:33:24 +0300
committerNino van Hooff <ninovanhooff@gmail.com>2020-02-14 18:33:24 +0300
commit507459660e0196c4bdc1770b347b6496718b0624 (patch)
treebb855dffeafca35da268e923e4efe32aa3426c61 /plugins/Toolbox/src/CloudSync/SyncOrchestrator.py
parent089561dd2239c0dd14c90e598121ab19dd047f3a (diff)
Refactor: rename CloudPackageManager to CloudApiClient
Diffstat (limited to 'plugins/Toolbox/src/CloudSync/SyncOrchestrator.py')
-rw-r--r--plugins/Toolbox/src/CloudSync/SyncOrchestrator.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins/Toolbox/src/CloudSync/SyncOrchestrator.py b/plugins/Toolbox/src/CloudSync/SyncOrchestrator.py
index c24703bf92..aed8c3f836 100644
--- a/plugins/Toolbox/src/CloudSync/SyncOrchestrator.py
+++ b/plugins/Toolbox/src/CloudSync/SyncOrchestrator.py
@@ -8,7 +8,7 @@ from UM.Message import Message
from UM.PluginRegistry import PluginRegistry
from cura.CuraApplication import CuraApplication
from .CloudPackageChecker import CloudPackageChecker
-from .CloudPackageManager import CloudPackageManager
+from .CloudApiClient import CloudApiClient
from .DiscrepanciesPresenter import DiscrepanciesPresenter
from .DownloadPresenter import DownloadPresenter
from .LicensePresenter import LicensePresenter
@@ -26,7 +26,7 @@ from .SubscribedPackagesModel import SubscribedPackagesModel
# - The DownloadPresenter shows a download progress dialog. It emits A tuple of succeeded and failed downloads
# - The LicensePresenter extracts licenses from the downloaded packages and presents a license for each package to
# be installed. It emits the `licenseAnswers` signal for accept or declines
# - The CloudPackageManager removes the declined packages from the account
# - The SyncOrchestrator uses PackageManager to install the downloaded packages and delete temp files.
# - The RestartApplicationPresenter notifies the user that a restart is required for changes to take effect
class SyncOrchestrator(Extension):
@@ -38,8 +38,8 @@ class SyncOrchestrator(Extension):
self._name = "SyncOrchestrator"
self._package_manager = app.getPackageManager()
- # Keep a reference to the CloudPackageManager. it watches for installed packages and subscribes to them
- self._cloud_package_manager = CloudPackageManager.getInstance(app) # type: CloudPackageManager
+ # Keep a reference to the CloudApiClient. it watches for installed packages and subscribes to them
+ self._cloud_api = CloudApiClient.getInstance(app) # type: CloudApiClient
self._checker = CloudPackageChecker(app) # type: CloudPackageChecker
self._checker.discrepancies.connect(self._onDiscrepancies)
@@ -87,7 +87,7 @@ class SyncOrchestrator(Extension):
continue
has_changes = True
else:
- self._cloud_package_manager.unsubscribe(item["package_id"])
+ self._cloud_api.unsubscribe(item["package_id"])
# delete temp file
os.remove(item["package_path"])
@@ -26,7 +26,7 @@ from .SubscribedPackagesModel import SubscribedPackagesModel
# - The LicensePresenter extracts licenses from the downloaded packages and presents a license for each package to
# be installed. It emits the `licenseAnswers` signal for accept or declines
-# - The CloudPackageManager removes the declined packages from the account
+# - The CloudApiClient removes the declined packages from the account
# - The SyncOrchestrator uses PackageManager to install the downloaded packages and delete temp files.
# - The RestartApplicationPresenter notifies the user that a restart is required for changes to take effect